<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:ext="xalan://es.uca.xmleye.xpath.XPathPathManager"
 xmlns:string="http://xml.apache.org/xalan/java/java.lang.String"
 xmlns:ppacl2="http://www.uca.es/xmleye/ppACL2-stylesheet"
 xmlns:util="http://www.uca.es/util">

<!-- Modo de información básica acerca de un nodo.                 -->
<!-- Sólo se darán detalles acerca del nodo que esté seleccionado. -->

<!-- EVENTOS -->

<xsl:template match="encapsulate|local" mode="ppacl2_printnode">
  <h2 class="section">
    <a href="#xpointer({ext:getPath(.,/)})"><xsl:value-of select="name(.)"/></a>
  </h2>
  <pre>
    <xsl:value-of select="@formula"/>
  </pre>
</xsl:template>

<xsl:template match="defthm|defun" mode="ppacl2_printnode">
  <h2 class="section">
   <a href="#xpointer({ext:getPath(.,/)})"><xsl:value-of select="@name"/></a>
  </h2>

  <pre>
    <xsl:value-of select="@formula"/>
  </pre>
</xsl:template>

<xsl:template match="thm" mode="ppacl2_printnode">
  <pre>
    <xsl:value-of select="@formula"/>
  </pre>
</xsl:template>

<xsl:template match="defpkg|includebook|certifybook" mode="ppacl2_printnode">
  <xsl:variable name="cmdname">
    <xsl:call-template name="util:to-upper">
      <xsl:with-param name="string">
	<xsl:value-of select="local-name(.)"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:variable>
  <h2>
   <a href="#xpointer({ext:getPath(.,/)})">
     <xsl:value-of select="concat($cmdname, ' ', @name)"/>
   </a>
  </h2>
</xsl:template>

<xsl:template match="subgoal" mode="ppacl2_printnode">
  <h2 class="section">
   <a href="#xpointer({ext:getPath(.,/)})"><xsl:value-of select="@label"/></a>
  </h2>
  <h3 class="subsection">
    <xsl:value-of select="$ppacl2:formula"/>
  </h3>
  <pre>
    <xsl:value-of select="@formula"/>
  </pre>
</xsl:template>

<!-- Reglas relacionadas con el uso de libros -->

<xsl:template match="checksum|verification|write_cert|compilation" mode="ppacl2_printnode">
  <xsl:apply-templates select="output" mode="ppacl2_printnode"/>
</xsl:template>

<!-- Demás partes variadas de las salidas -->

<xsl:template match="summary" mode="ppacl2_printnode">
    <h2 class="section"><xsl:value-of select="$ppacl2:summary"/></h2>

    <xsl:if test="warnings/warning">
       <h3><xsl:value-of select="$ppacl2:warnings"/></h3>
       <ol>
       <xsl:for-each select="warnings/warning">
         <li><xsl:value-of select="@type"/></li>
       </xsl:for-each>
       </ol>
    </xsl:if>

    <h3 class="subsection"><xsl:value-of select="$ppacl2:rules"/></h3>
    <xsl:apply-templates select="rules" mode="ppacl2_printnode"/>

    <h3 class="subsection"><xsl:value-of select="$ppacl2:times"/></h3>
    <table width="60%" align="center" border="1">
      <tr>
        <th width="40%" class="tablekey"><xsl:value-of select="$ppacl2:name"/></th>
        <th width="60%" class="tablevalue"><xsl:value-of select="$ppacl2:time"/></th>
      </tr>
      <tr> 
        <td><xsl:value-of select="$ppacl2:prove"/></td>
        <td><xsl:value-of select="time/@prove"/></td>
      </tr>
      <tr> 
        <td><xsl:value-of select="$ppacl2:print"/></td>
        <td><xsl:value-of select="time/@print"/></td>
      </tr>
      <tr> 
        <td><xsl:value-of select="$ppacl2:other"/></td>
        <td><xsl:value-of select="time/@other"/></td>
      </tr>
      <tr> 
        <td class="highlight"><xsl:value-of select="$ppacl2:total"/></td>
        <td><font class="highlight"><xsl:value-of select="time/@total"/></font></td>
      </tr>
    </table>
</xsl:template>

<xsl:template match="output" mode="ppacl2_printnode">
 <xsl:for-each select="*">
   <xsl:choose>
    <xsl:when test="self::sexpr">
      <pre><xsl:value-of select="."/></pre>
    </xsl:when>
    <xsl:otherwise>
      <p><xsl:value-of select="."/></p>
    </xsl:otherwise>
   </xsl:choose>
 </xsl:for-each>
</xsl:template>

<xsl:template match="rules" mode="ppacl2_printnode">
    <xsl:choose>
      <xsl:when test="rule">
        <table width="80%" align="center" border="1">
         <tr>
           <th width="40%" class="tablekey"><xsl:value-of select="$ppacl2:type"/></th>
           <th width="60%" class="tablevalue"><xsl:value-of select="$ppacl2:name"/></th>
         </tr>
	 <xsl:apply-templates select="rule" mode="ppacl2_printnode"/>
        </table>
      </xsl:when>
      <xsl:otherwise>
        <p class="info"><xsl:value-of select="$ppacl2:norules"/></p>
      </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="rule" mode="ppacl2_printnode">
          <tr>
            <td><xsl:value-of select="@type"/></td>
            <td>
              <xsl:choose>
                <xsl:when test="@href and key('uid',@href)">
                 <a href="#xpointer({ext:getPath(key('uid',@href),/)})"><xsl:value-of select="@name"/></a>
                </xsl:when>
                <xsl:when test="@href">
                 <a href="{@href}"><xsl:value-of select="@name"/></a>
                </xsl:when>
                <xsl:otherwise>
                 <xsl:value-of select="@name"/>
                </xsl:otherwise>
              </xsl:choose>
            </td>
          </tr>
</xsl:template>

<xsl:template match="warning" mode="ppacl2_printnode">
  <table width="80%" padding="1" align="center">
    <tr><th class="warning">
         <xsl:value-of select="$ppacl2:warning"/>: <xsl:value-of select="@type"/>
    </th></tr>
    <tr><td class="warning">
     <xsl:value-of select="."/>
    </td></tr>
  </table>
</xsl:template>

<xsl:template match="observation" mode="ppacl2_printnode">
  <table width="80%" padding="1" align="center">
    <tr><th class="observation"><xsl:value-of select="$ppacl2:observation"/></th></tr>
    <tr><td class="observation">
     <xsl:value-of select="."/>
    </td></tr>
  </table>
</xsl:template>

<xsl:template match="error" mode="ppacl2_printnode">
  <table width="80%" padding="1" align="center">
    <tr><th class="error"><xsl:value-of select="$ppacl2:error"/></th></tr>
    <tr><td class="error">
     <xsl:value-of select="."/>
    </td></tr>
  </table>
</xsl:template>

<xsl:template match="suggestions" mode="ppacl2_printnode">
    <h2 class="subsection">
      <xsl:value-of select="concat($ppacl2:sugg, ' ', @hint)"/>
        <xsl:if test="@adapt">
          <xsl:value-of select="concat(' ', $ppacl2:adapt, ' ', @adapt)"/>
        </xsl:if>
      <xsl:value-of select="concat(' ', $ppacl2:obtained, ':')"/>
    </h2>

    <xsl:choose>
      <xsl:when test="rule">
        <table width="80%" align="center" border="1">
         <tr>
           <th width="40%" class="tablekey"><xsl:value-of select="$ppacl2:type"/></th>
           <th width="60%" class="tablevalue"><xsl:value-of select="$ppacl2:name"/></th>
         </tr>
	 <xsl:apply-templates select="rule" mode="ppacl2_printnode"/>
      </table>
      </xsl:when>
      <xsl:otherwise>
        <p class="info"><xsl:value-of select="$ppacl2:norules"/></p>
      </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="rule_classes" mode="ppacl2_printnode">
  <h2 class="subsection"><xsl:value-of select="$ppacl2:rule_classes"/></h2>
  <ol>
    <xsl:apply-templates select="rule_class" mode="ppacl2_printnode"/>
  </ol>
</xsl:template>

<xsl:template match="rule_class" mode="ppacl2_printnode">
  <xsl:choose>
    <xsl:when test="clique">
      <li>
        <xsl:value-of select="concat($ppacl2:clique, ': ', @type)"/>
        <xsl:apply-templates select="clique" mode="ppacl2_printnode"/>
      </li>
    </xsl:when>
    <xsl:otherwise>
      <li>
        <xsl:value-of select="@type"/>
      </li>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="clique" mode="ppacl2_printnode">
  <ul>
   <xsl:for-each select="clique_func">
     <li><xsl:value-of select="concat(@name, ' (', @mask, ')')"/></li>
   </xsl:for-each>
  </ul>
</xsl:template>

<xsl:template match="type" mode="ppacl2_printnode">
  <h2 class="section"><xsl:value-of select="$ppacl2:defuntype"/></h2>

  <h3 class="subsection"><xsl:value-of select="$ppacl2:usedrules"/></h3>
  <xsl:apply-templates select="rules" mode="ppacl2_printnode"/>

  <h3 class="subsection"><xsl:value-of select="$ppacl2:output"/></h3>
  <xsl:apply-templates select="output" mode="ppacl2_printnode"/>
</xsl:template>

<xsl:template match="signatures" mode="ppacl2_printnode">
  <h3 class="subsection"><xsl:value-of select="$ppacl2:signatures"/></h3>
  <table width="80%" border="1" align="center">
  <tr>
    <th class="tablekey" width="40%"><xsl:value-of select="$ppacl2:funcname"/></th>
    <th class="tablevalue"><xsl:value-of select="$ppacl2:signinput"/></th>
    <th class="tablevalue"><xsl:value-of select="$ppacl2:signoutput"/></th>
    <th class="tablevalue"><xsl:value-of select="$ppacl2:stdobjs"/></th>
  </tr>
  <xsl:apply-templates select="signature" mode="ppacl2_printnode"/>
  </table>
</xsl:template>

<xsl:template match="signature" mode="ppacl2_printnode">
  <tr>
    <td><xsl:value-of select="@func"/></td>
    <td><xsl:value-of select="@signInput"/></td>
    <td><xsl:value-of select="@signOutput"/></td>
    <td><xsl:value-of select="@stdobjs"/></td>
  </tr>
</xsl:template>

<xsl:template match="deps_storage" mode="ppacl2_printnode">
  <h2 class="section"><xsl:value-of select="$ppacl2:deps_storage"/></h2>

  <h3 class="subsection"><xsl:value-of select="$ppacl2:usedrules"/></h3>
  <xsl:apply-templates select="rules" mode="ppacl2_printnode"/>

  <h3 class="subsection"><xsl:value-of select="$ppacl2:output"/></h3>
  <xsl:apply-templates select="output" mode="ppacl2_printnode"/>
</xsl:template>

<xsl:template match="restriction_func" mode="ppacl2_printnode">
  <h3 class="subsection">
    <xsl:value-of select="concat($ppacl2:restriction_func, ': ', @func)"/>
  </h3>
  <pre><xsl:value-of select="sexpr"/></pre>
</xsl:template>

<xsl:template match="usedby" mode="ppacl2_printnode">
  <h3 class="subsection">
    <xsl:value-of select="$ppacl2:usedby"/>
  </h3>
  
  <xsl:choose>
    <xsl:when test="use">
       <ul>
         <xsl:apply-templates select="use" mode="ppacl2_printnode"/>
       </ul>
    </xsl:when>
    <xsl:otherwise>
      <p class="info"><xsl:value-of select="$ppacl2:nouses"/></p>
    </xsl:otherwise>
  </xsl:choose>

</xsl:template>

<xsl:template match="use" mode="ppacl2_printnode">
  <li>
     <xsl:for-each select="key('uid', @href)">
     <a href="#xpointer({ext:getPath(.,/)})">
       <xsl:choose>
         <xsl:when test="@nodelabel">
           <xsl:value-of select="@nodelabel"/>
         </xsl:when>
	 <xsl:when test="@name">
	   <xsl:value-of select="concat(name(.), '-', @name)"/>
         </xsl:when>
         <xsl:otherwise>
	   <xsl:value-of select="name(.)"/>
         </xsl:otherwise>
       </xsl:choose>
     </a>
     </xsl:for-each>
  </li>
</xsl:template>

<!-- Retiramos la regla por defecto para cada modo -->
<xsl:template match="*" mode="ppacl2_printnode"/>

</xsl:stylesheet>
